@@ -1,5 +1,5 @@
 /* Gnome Music Player Client (GMPC)
- * Copyright (C) 2004-2009 Qball Cow <qball@sarine.nl>
+ * Copyright (C) 2004-2010 Qball Cow <qball@sarine.nl>
  * Project homepage: http://gmpc.wikia.com/
  
  * This program is free software; you can redistribute it and/or modify
@@ -39,7 +39,7 @@ void mpd_song_markup_escaped(char *buffer, int size, char *markup, mpd_Song *son
  * this draws a 1 pixel border around a pixbuf.
  * It doesn't work for all color depths (I think)
  */
-void screenshot_add_border (GdkPixbuf **src);
+void screenshot_add_border (GdkPixbuf *src);
 
 void open_uri(const gchar *uri);
 int *split_version(const char *uri);
